@@ -119,12 +119,10 @@ int _fastcall common_startdisk(long newrowsize, long newcolsize, int colors)
    long longtmp;
    unsigned int cache_size;
    BYTE far *tempfar = NULL;
-   char *savenameptr;
-
    if (diskflag)
       enddisk();
    if (dotmode == 11) { /* otherwise, real screen also in use, don't hit it */
-      char buf[50];
+      char buf[20];
       static FCODE fmsg1[] = {"'Disk-Video' mode"};
       static FCODE fmsg2[] = {"Screen resolution: "};
       static FCODE fsname[] = {"Save name: "};
@@ -148,17 +146,12 @@ int _fastcall common_startdisk(long newrowsize, long newcolsize, int colors)
          putstring(-1,-1,C_DVID_LO,buf);
          }
       putstring(BOXROW+6,BOXCOL+4,C_DVID_LO,fsname);
-      savenameptr = strrchr(savename, SLASHC); /* check for full path */
-      if(savenameptr == NULL)
-         savenameptr = savename;
-      else
-         savenameptr++; /* point past slash */
-      sprintf(buf,"%s",savenameptr);
+      sprintf(buf,"%s",savename);
       putstring(-1,-1,C_DVID_LO,buf);
       putstring(BOXROW+10,BOXCOL+4,C_DVID_LO,stat);
       {
       static FCODE o_msg[] = {"clearing the 'screen'"};
-      char msg[sizeof(o_msg)];
+      char far msg[sizeof(o_msg)];
       far_strcpy(msg,o_msg);
       dvid_status(0,msg);
       }
