@@ -10,8 +10,6 @@ fractal routines.
 #include <string.h>
 #ifdef __TURBOC__
 #include <alloc.h>
-#elif defined(__APPLE__)
-#include <malloc/malloc.h>
 #elif !defined(__386BSD__)
 #include <malloc.h>
 #endif
@@ -23,7 +21,7 @@ fractal routines.
 
 
 int bf_math = 0;
-LDBL b_const;
+double b_const;
 
 #if (_MSC_VER >= 700)
 #pragma code_seg ("bigsetup_text")     /* place following in an overlay */
