@@ -41,8 +41,6 @@ an appropriate setup, per_image, per_pixel, and orbit routines.
 #include <string.h>
 #ifdef __TURBOC__
 #include <alloc.h>
-#elif defined(__APPLE__)
-#include <malloc/malloc.h>
 #elif !defined(__386BSD__)
 #include <malloc.h>
 #endif
@@ -98,14 +96,10 @@ _LCMPLX *longparm; /* used here and in jb.c */
 /*              These variables are external for speed's sake only      */
 /* -------------------------------------------------------------------- */
 
-#ifndef XFRACT
-#define LDBL            double
-#endif
-
-LDBL sinx,cosx;
-LDBL siny,cosy;
-LDBL tmpexp;
-LDBL tempsqrx,tempsqry;
+double sinx,cosx;
+double siny,cosy;
+double tmpexp;
+double tempsqrx,tempsqry;
 
 double foldxinitx,foldyinity,foldxinity,foldyinitx;
 long oldxinitx,oldyinity,oldxinity,oldyinitx;
@@ -3437,7 +3431,7 @@ MandelbrotMix4fpFractal(void) /* from formula by Jim Muth */
 #undef K
 #undef L
 
-extern LDBL b_const;
+double b_const;
 
 int DivideBrot5Setup(void)
 {
